@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -147,7 +147,6 @@ gst_ffmpeg_dct_algo_get_type (void)
       {FF_DCT_FASTINT, "Fast Integer", "fastint"},
       {FF_DCT_INT, "Accurate Integer", "int"},
       {FF_DCT_MMX, "MMX", "mmx"},
-      {FF_DCT_MLIB, "MLIB", "mlib"},
       {FF_DCT_ALTIVEC, "ALTIVEC", "altivec"},
       {FF_DCT_FAAN, "FAAN", "faan"},
       {0, NULL, NULL},
@@ -173,8 +172,6 @@ gst_ffmpeg_idct_algo_get_type (void)
       {FF_IDCT_SIMPLE, "Simple", "simple"},
       {FF_IDCT_SIMPLEMMX, "Simple MMX", "simplemmx"},
       {FF_IDCT_LIBMPEG2MMX, "LIBMPEG2MMX", "libmpeg2mmx"},
-      {FF_IDCT_PS2, "PS2", "ps2"},
-      {FF_IDCT_MLIB, "MLIB", "mlib"},
       {FF_IDCT_ARM, "ARM", "arm"},
       {FF_IDCT_ALTIVEC, "ALTIVEC", "altivec"},
       {FF_IDCT_SH4, "SH4", "sh4"},
@@ -263,16 +260,11 @@ gst_ffmpeg_flags_get_type (void)
 
   if (!ffmpeg_flags_type) {
     static const GFlagsValue ffmpeg_flags[] = {
-      {CODEC_FLAG_OBMC, "Use overlapped block motion compensation (h263+)",
-          "obmc"},
       {CODEC_FLAG_QSCALE, "Use fixed qscale", "qscale"},
       {CODEC_FLAG_4MV, "Allow 4 MV per MB", "4mv"},
-      {CODEC_FLAG_H263P_AIV, "H.263 alternative inter VLC", "aiv"},
       {CODEC_FLAG_QPEL, "Quartel Pel Motion Compensation", "qpel"},
       {CODEC_FLAG_GMC, "GMC", "gmc"},
       {CODEC_FLAG_MV0, "Always try a MB with MV (0,0)", "mv0"},
-      {CODEC_FLAG_PART,
-          "Store MV, DC and AC coefficients in seperate partitions", "part"},
       {CODEC_FLAG_LOOP_FILTER, "Loop filter", "loop-filter"},
       {CODEC_FLAG_GRAY, "Only decode/encode grayscale", "gray"},
       {CODEC_FLAG_NORMALIZE_AQP,
@@ -282,13 +274,9 @@ gst_ffmpeg_flags_get_type (void)
           "global-headers"},
       {CODEC_FLAG_AC_PRED, "H263 Advanced Intra Coding / MPEG4 AC prediction",
           "aic"},
-      {CODEC_FLAG_H263P_UMV, "Unlimited Motion Vector", "umv"},
       {CODEC_FLAG_CBP_RD, "Rate Distoration Optimization for CBP", "cbp-rd"},
       {CODEC_FLAG_QP_RD, "Rate Distoration Optimization for QP selection",
           "qp-rd"},
-      {CODEC_FLAG_H263P_SLICE_STRUCT, "H263 slice struct", "ss"},
-      {CODEC_FLAG_SVCD_SCAN_OFFSET,
-          "Reserve space for SVCD scan offset user data", "scanoffset"},
       {CODEC_FLAG_CLOSED_GOP, "Closed GOP", "closedgop"},
       {0, NULL, NULL},
     };
@@ -314,7 +302,7 @@ struct _GParamSpecData
   /* if TRUE, try to get the default from lavc and ignore the paramspec default */
   gboolean lavc_default;
 
-  /* these lists are arrays terminated by CODEC_ID_NONE entry:
+  /* these lists are arrays terminated by AV_CODEC_ID_NONE entry:
    * property applies to a codec if it's not in the exclude_list
    * and in exclude_list (or the latter is NULL) */
   gint *include_list;
@@ -358,22 +346,22 @@ G_STMT_START {                                                          \
 /* some typical include and exclude lists; modify and/or add where needed */
 
 static gint mpeg[] = {
-  CODEC_ID_MPEG4,
-  CODEC_ID_MSMPEG4V1,
-  CODEC_ID_MSMPEG4V2,
-  CODEC_ID_MSMPEG4V3,
-  CODEC_ID_MPEG1VIDEO,
-  CODEC_ID_MPEG2VIDEO,
-  CODEC_ID_H263P,
-  CODEC_ID_FLV1,
-  CODEC_ID_H263,
-  CODEC_ID_NONE
+  AV_CODEC_ID_MPEG4,
+  AV_CODEC_ID_MSMPEG4V1,
+  AV_CODEC_ID_MSMPEG4V2,
+  AV_CODEC_ID_MSMPEG4V3,
+  AV_CODEC_ID_MPEG1VIDEO,
+  AV_CODEC_ID_MPEG2VIDEO,
+  AV_CODEC_ID_H263P,
+  AV_CODEC_ID_FLV1,
+  AV_CODEC_ID_H263,
+  AV_CODEC_ID_NONE
 };
 
 static gint huffyuv[] = {
-  CODEC_ID_HUFFYUV,
-  CODEC_ID_FFVHUFF,
-  CODEC_ID_NONE
+  AV_CODEC_ID_HUFFYUV,
+  AV_CODEC_ID_FFVHUFF,
+  AV_CODEC_ID_NONE
 };
 
 /* Properties should be added here for registration into the config store.
@@ -719,7 +707,7 @@ gst_ffmpeg_cfg_codec_has_pspec (enum CodecID codec_id, GParamSpec * pspec)
 
   /* check if excluded first */
   if ((codec = qdata->exclude_list)) {
-    for (; *codec != CODEC_ID_NONE; ++codec) {
+    for (; *codec != AV_CODEC_ID_NONE; ++codec) {
       if (*codec == codec_id)
         return FALSE;
     }
@@ -727,7 +715,7 @@ gst_ffmpeg_cfg_codec_has_pspec (enum CodecID codec_id, GParamSpec * pspec)
 
   /* no include list means it is accepted */
   if ((codec = qdata->include_list)) {
-    for (; *codec != CODEC_ID_NONE; ++codec) {
+    for (; *codec != AV_CODEC_ID_NONE; ++codec) {
       if (*codec == codec_id)
         ret = TRUE;
     }
@@ -750,10 +738,8 @@ gst_ffmpeg_cfg_install_property (GstFFMpegVidEncClass * klass, guint base)
   prop_id = base;
   g_return_if_fail (base > 0);
 
-  ctx = avcodec_alloc_context ();
-  if (ctx)
-    avcodec_get_context_defaults (ctx);
-  else
+  ctx = avcodec_alloc_context3 (klass->in_plugin);
+  if (!ctx)
     g_warning ("could not get context");
 
   for (list = property_list; list; list = list->next) {
@@ -853,8 +839,10 @@ gst_ffmpeg_cfg_install_property (GstFFMpegVidEncClass * klass, guint base)
     }
   }
 
-  if (ctx)
+  if (ctx) {
+    gst_ffmpeg_avcodec_close (ctx);
     av_free (ctx);
+  }
 }
 
 /* returns TRUE if it is a known property for this config system,
