@@ -254,6 +254,10 @@ gst_ffmpegmux_base_init (gpointer g_class)
     const gint rates[] = { 44100, 22050, 11025 };
 
     gst_ffmpeg_mux_simple_caps_set_int_list (audiosinkcaps, "rate", 3, rates);
+  } else if (strcmp (in_plugin->name, "dv") == 0) {
+    gst_caps_set_simple (audiosinkcaps,
+        "rate", G_TYPE_INT, 48000, "channels", G_TYPE_INT, 2, NULL);
+
   } else if (strcmp (in_plugin->name, "gif") == 0) {
     if (videosinkcaps)
       gst_caps_unref (videosinkcaps);
@@ -474,7 +478,7 @@ gst_ffmpegmux_setcaps (GstPad * pad, GstCaps * caps)
   collect_pad = (GstFFMpegMuxPad *) gst_pad_get_element_private (pad);
 
   st = ffmpegmux->context->streams[collect_pad->padnum];
-  av_opt_set_int (&ffmpegmux->context, "preload", ffmpegmux->preload, 0);
+  av_opt_set_int (ffmpegmux->context, "preload", ffmpegmux->preload, 0);
   ffmpegmux->context->max_delay = ffmpegmux->max_delay;
 
   /* for the format-specific guesses, we'll go to
@@ -939,6 +943,8 @@ gst_ffmpegmux_register (GstPlugin * plugin)
     while (*p) {
       if (*p == '.')
         *p = '_';
+      if (*p == ',')
+        *p = '_';
       p++;
     }
 
